@@ -298,43 +298,17 @@ class Base_Page(Borg, unittest.TestCase):
             self.write(str(e))
             self.exceptions.append("Error when setting up the screenshot directory")
 
-    def assert_true(self, condition, error_message=None, level='info'):
+    def assert_true(self, condition, success_message=None, error_message=None, level='info'):
+        self.conditional_write(condition, success_message, error_message, level)
+
         if self.non_breakable == 'N':
             assert_that(condition, equal_to(True), error_message)
-        elif self.non_breakable == 'Y':
-            print('testing')
-            self.mini_check_counter += 1
-            if level.lower() == "inverse":
-                if condition is True:
-                    self.write("action performed", level='error')
-                else:
-                    self.write(error_message, level='info')
-                    self.mini_check_pass_counter += 1
-            else:
-                if condition is True:
-                    self.write("action performed", level='info')
-                    self.mini_check_pass_counter += 1
-                else:
-                    self.write(error_message, level='error')
 
-    def assert_false(self, condition, pass_massage=None, error_message=None, level='info'):
+    def assert_false(self, condition, success_message=None, error_message=None, level='inverse'):
+        self.conditional_write(condition, success_message, error_message, level)
+
         if self.non_breakable == 'N':
             assert_that(condition, equal_to(False), error_message)
-        elif self.non_breakable == 'Y':
-            print('testing')
-            self.mini_check_counter += 1
-            if level.lower() == "inverse":
-                if condition is True:
-                    self.write(error_message, level='error')
-                else:
-                    self.write("Expected results performed", level='info')
-                    self.mini_check_pass_counter += 1
-            else:
-                if condition is True:
-                    self.write(pass_massage, level='info')
-                    self.mini_check_pass_counter += 1
-                else:
-                    self.write(error_message, level='error')
 
     def get_screenshot_dir(self, os_name, os_version, browser, browser_version, overwrite_flag=False):
         "Get the name of the test"
@@ -1280,9 +1254,9 @@ class Base_Page(Borg, unittest.TestCase):
         self.mini_check_counter += 1
         if level.lower() == "inverse":
             if flag is True:
-                self.write(positive, level='error')
+                self.write(negative, level='error')
             else:
-                self.write(negative, level='info')
+                self.write(positive, level='info')
                 self.mini_check_pass_counter += 1
         else:
             if flag is True:
