@@ -1,10 +1,9 @@
 """
 Class to hold miscellaneous but useful decorators for our framework
 """
-
-from inspect import getfullargspec
-
 import pytest
+from pytest_html import extras
+from inspect import getfullargspec
 
 
 class Wrapit():
@@ -30,7 +29,7 @@ class Wrapit():
 
         # Usage: Make this the first decorator to a method (right above the 'def function_name' line)
         # Otherwise, we cannot name the screenshot with the name of the function that called it
-        def wrapper(*args, **kwargs):
+        def wrapper(request, *args, **kwargs):
             """Original code"""
             # result = func(*args, **kwargs)
             # screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
@@ -47,19 +46,14 @@ class Wrapit():
             if args[0].screenshot == 'all':
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
-                screenshot = args[0].save_screenshot(screenshot_name)
-                # args[0].save_screenshot(screenshot_name)
-                pytest.config.pluginmanager.get_plugin("html").attach(name=screenshot_name, contents=screenshot,
-                                                                      extension=".png")
+                args[0].save_screenshot(screenshot_name)
+                extra = extras.image(screenshot_name)
+                request.config.pytest_html.extend_html(request, "Screenshot", extra)
 
             elif args[0].screenshot == 'failonly' and result is False:
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
-                screenshot = args[0].save_screenshot(screenshot_name)
-                # args[0].save_screenshot(screenshot_name)
-                pytest.config.pluginmanager.get_plugin("html").attach(name=screenshot_name, contents=screenshot,
-                                                                      extension=".png")
-
+                args[0].save_screenshot(screenshot_name)
             return result
 
         return wrapper
